@@ -14,10 +14,6 @@ impl Default for ThreadHandle {
 }
 
 impl ThreadHandle {
-    pub fn new(handle: JoinHandle) -> Self {
-        Self(Arc::new(Mutex::new(Some(handle))))
-    }
-
     pub(crate) fn register(&self, handle: JoinHandle) {
         *self.0.lock() = Some(handle);
     }
@@ -28,16 +24,10 @@ impl ThreadHandle {
 
     pub(crate) fn wait(&self, context: &'static str) -> Result<()> {
         if let Some(handle) = self.take() {
-            handle.join().expect(context)?
+            if handle.thread().id() != thread::current().id() {
+                handle.join().expect(context)?;
+            }
         }
         Ok(())
     }
-
-    pub(crate) fn is_current(&self) -> bool {
-        self.0
-            .lock()
-            .as_ref()
-            .map(|handle| handle.thread().id() == thread::current().id())
-            .unwrap_or_default()
-    }
 }
